# MCP

The MCP gateway uses [FastMCP 3.x](https://gofastmcp.com/) to expose LOOM
workers, pipelines, query backends, Workshop operations, and session
management as MCP tools.

## Server

::: loom.mcp.server

## Bridge

::: loom.mcp.bridge

## Config

::: loom.mcp.config

## Discovery

::: loom.mcp.discovery

## Resources

::: loom.mcp.resources

## Session Bridge

::: loom.mcp.session_bridge

## Session Registry

::: loom.mcp.session_registry
